#
# spec file for package python-oci-sdk
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-oci-sdk
Version:        2.11.0
Release:        bp153.1.20
Summary:        Oracle Cloud Infrastructure Python SDK
License:        UPL-1.0 OR Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/oracle/oci-python-sdk
Source:         https://github.com/oracle/oci-python-sdk/archive/v%{version}.tar.gz
Patch0:         ops_relax-python-depends.patch
Patch1:         ops_fixture-order.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyJWT
Requires:       python-certifi
Requires:       python-cryptography >= 2.1.4
Requires:       python-httpsig_cffi
Requires:       python-pyOpenSSL >= 17.5.0
Requires:       python-python-dateutil < 3.0.0
Requires:       python-python-dateutil >= 2.5.3
Requires:       python-pytz >= 2016.10
Requires:       python-requests
Requires:       python-six
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyJWT}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module cryptography >= 2.1.4}
BuildRequires:  %{python_module httpsig_cffi}
BuildRequires:  %{python_module pyOpenSSL >= 17.5.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil < 3.0.0}
BuildRequires:  %{python_module python-dateutil >= 2.5.3}
BuildRequires:  %{python_module pytz >= 2016.10}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module vcrpy}
%if %{with python2}
BuildRequires:  python-configparser >= 3.5.0
%endif
# /SECTION
%ifpython2
Requires:       python-configparser >= 3.5.0
%endif
%python_subpackages

%description
Python SDK for Oracle Cloud Infrastructure. Python 2.7+ and 3.5+ are supported.

%prep
%setup -q -n oci-python-sdk-%{version}
%patch0 -p1
%patch1 -p1
# Remove vendored packages
rm -rf src/oci/_vendor/
# Fix includes
sed -i 's/from \._vendor //' src/oci/*.py
sed -i 's/from oci._vendor //' src/oci/*.py src/oci/analytics/*.py src/oci/apigateway/*.py src/oci/application_migration/*.py src/oci/announcements_service/*.py src/oci/audit/*.py src/oci/auth/*.py src/oci/auth/signers/*.py src/oci/autoscaling/*.py src/oci/budget/*.py src/oci/container_engine/*.py src/oci/dns/*.py src/oci/core/*.py src/oci/database/*.py src/oci/data_catalog/*.py src/oci/data_flow/*.py src/oci/data_science/*.py src/oci/dts/*.py src/oci/email/*.py src/oci/events/*.py src/oci/file_storage/*.py src/oci/functions/*.py src/oci/healthchecks/*.py src/oci/integration/*.py src/oci/key_management/*.py src/oci/marketplace/*.py src/oci/limits/*.py src/oci/load_balancer/*.py src/oci/monitoring/*.py src/oci/nosql/*.py src/oci/oda/*.py src/oci/object_storage/*.py src/oci/oce/*.py src/oci/ons/*.py src/oci/object_storage/transfer/*.py src/oci/object_storage/transfer/internal/*.py src/oci/os_management/*.py src/oci/resource_manager/*.py src/oci/streaming/*.py src/oci/identity/*.py src/oci/resource_search/*.py src/oci/waas/*.py src/oci/work_requests/*.py tests/*.py
sed -i 's/ oci._vendor.jwt as//' src/oci/auth/*.py
sed -i 's/oci\._vendor\.//' src/oci/*.py src/oci/retry/*.py src/oci/object_storage/transfer/internal/*.py tests/*.py
sed -i 's/from . import vcr_mods//' tests/test_config_container.py

%build
%python_build

%check
export PYTHONDONTWRITEBYTECODE=1
%pytest tests/unit tests/integ -s

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Mar 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.11.0
  + Support for Events service integration with alerts in the Budgets service
  + The parameters sort_by and lifecycle_state type from Budgets
    service are changed from str to enum
- from version 2.10.7
  + Support for updating the shape of a Database System in the Database service
  + Support for generating CPE configurations for download in the Networking service
  + Support for private IPs and fault domains of cluster nodes in the Container
    Engine for Kubernetes service
  + Support for calling Oracle Cloud Infrastructure services in the ca-montreal-1 region
  + Fixed missed parameter when invoking request signing for delegation token
- from version 2.10.6
  + Support for restarting autonomous databases in the Database service
  + Support for private endpoints on autonomous databases in the Database service
  + Support for IP-based policies in the Identity service
  + Support for management of OAuth 2.0 client credentials in the Identity service
  + Support for OCI Functions as a subscription protocol in the Notifications service
- from version 2.10.5
  + Support for the NoSQL Database service
  + Support for filtering database versions by storage management
    type in the Database service
  + Support for specifying paid listing types within pricing models
    in the Marketplace service
  + Support for primary and non-primary instance types in the
    Content and Experience service
- from version 2.10.4
  + Support for listing supported database versions for Autonomous Database Serverless,
    and selecting a version at provisioning time in the Database service
  + Support for TCP proxy protocol versions on listener connection
    configurations in the Load Balancer service
  + Support for calling the Notifications service in alternate realms
  + Support for calling Oracle Cloud Infrastructure services in the
    eu-amsterdam-1 and me-jeddah-1 regions
- Update file list to fix Python imports for unvendoring
* Fri Feb  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.10.3
  + Support for the Data Science service
  + Support for calling Oracle Cloud Infrastructure services
    in the ap-osaka-1 and ap-melbourne-1 regions
- from version 2.10.2
  + Support for the Application Migration service
  + Support for the Data Flow service
  + Support for the Data Catalog service
  + Support for cross-shape Data Guard in the Database service
  + Support for offline data export in the Data Transfer service
- from version 2.10.1
  + Support for getting DRG redundancy status in the Networking service
  + Support for cloning autonomous databases from backups in the Database service
- from version 2.10.0
  + Support for a description field on route rules and security
    rules in the Networking service
  + Support for starting and stopping Digital Assistant instances
    in the Digital Assistant service
  + Support for shared database homes on Exadata, bare metal, and virtual
    machine instances in the Database service
  + Support for tracking a number of Database service operations
    through the Work Requests service
  + Field db_home_id in list_databases from database service is
    changed from required to optional
- Refresh patches for new version
  + ops_fixture-order.patch
  + ops_relax-python-depends.patch
- Update file list to fix Python imports for unvendoring
* Wed Jan 29 2020 Sean Marlow <sean.marlow@suse.com>
- Update Url in spec to point to the upstream GitHub project.
* Fri Jan 17 2020 Sean Marlow <sean.marlow@suse.com>
- Add missing requirements. PyJWT, requests, httpsig_cffi,
  and six are required for tests and runtime.
* Sun Jan 12 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.9.0
  + Support for optionally specifying the corporate proxy field when
    creating Exadata infrastructure in the Database service
  + Support for maintenance windows, and rescheduling maintenance runs,
    on autonomous container databases in the Database service
  + Provide example on how to use key_content for python SDK configuration
  + Field ``host_name`` in ``NodeDetails`` from database
    service is changed from optional to required
* Wed Jan  8 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.8.0
  + Support for the API Gateway service
  + Support for the OS Management service
  + Support for the Marketplace service
  + Support for "default"-type vaults in the Key Management service
  + Support for bringing your own keys in the Key Management service
  + Support for cross-region backups of boot volumes in the Block Storage service
  + Support for top-level TSIG keys in the DNS service
  + Support for resizing virtual machine instances to different shapes in the Compute service
  + Support for management configuration of cloud agents in the Compute service
  + Support for launching node pools using image IDs in the Container Engine for Kubernetes service
  + Removed support for v1 auth tokens in kubeconfig files in the
    CreateClusterKubeconfigContentDetails class of the Container Engine for Kubernetes service
  + Removed the IDCS access token requirement on the delete deleteOceInstance operation in the
    Content and Experience service, which is why the DeleteOceInstanceDetails class was removed
  + Set compartment_id as a required parameter in list_stream_pools for streaming service
- from version 2.7.1
  + Support for etags on results of the List Objects API in the Object Storage service
  + Support for OCIDs on buckets in the Object Storage service
  + Support for content-disposition and cache-control headers
    on objects in the Object Storage service
  + Support for recovering deleted compartments in the Identity service
  + Support for sharing volumes across multiple instances in the Block Storage service
  + Support for connect harnesses and stream pools in the Streaming service
  + Support for associating file storage mount targets with network
    security groups in the File Storage service
  + Support for calling Oracle Cloud Infrastructure services in the uk-gov-london-1 region
  + Add default connection timeout(10s) and read timeout(60s) for Python SDK client
  + Add contents table to client documentation
  + Fix the issue of the second style of pagination
- from version 2.7.0
  + Support for maintenance windows on autonomous databases in the Database service
  + Support for getting the compute units (OCPUs) of an Exadata autonomous
    transaction processing - dedicated resource in the Database service
  + Create database home from VM_CLUSTER_BACKUP is removed from Database Service
- from version 2.6.5
  + Support for four-byte autonomous system numbers (ASNs) on FastConnect
    resources in the Networking service
  + Support for choosing fault domains when creating instance pools in the Compute service
  + Support for allowing connections from only specific VCNs to autonomous
    data warehouse and autonomous transaction processing instances in the Database service
  + Support for Streaming Client Non-Regional
- from version 2.6.4
  + Support for access to APEX and SQL Dev features on autonomous transaction processing
    and autonomous data warehouse resources in the Database service
  + Support for registering / deregistering autonomous transaction processing and
    autonomous data warehouse resources with Data Safe in the Database service
  + Support for redirecting HTTP / HTTPS request URIs to different URIs in the Load Balancing service
  + Support for specifying compartments on options APIs in the Container Engine for Kubernetes service
  + Support for volume performance units on block volumes in the Block Storage service
- from version 2.6.3
  + Support for the Analytics Cloud service
  + Support for the Integration Cloud service
  + Support for IKE versions in IPSec connections in the Virtual Networking service
  + Support for getting a stack's Terraform state in the Resource Manager service
- Add patch to add compatibility with older version of pytest
  + ops_fixture-order.patch
- Adjust BuildRequires and Requires to reduce them to the actual dependencies
* Mon Nov  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.6.2
  + Support for wallet rotation operations on Autonomous Databases in the Database service
  + Support for adding and removing image shape compatibility entries in the Compute service
  + Support for managing redirects in the Web Application Acceleration and Security service
  + Support for migrating zones from the Dyn HTTP Redirect Service
    to Oracle Cloud Infrastructure in the DNS service
- from version 2.6.1
  + Support for the Digital Assistant service
  + Support for work requests on Instance Pool operations in the Compute service
- from version 2.6.0
  + Support for the new schema for events in the Audit service
  + Support for entitlements in the Data Transfer service
  + Support for custom scheduled backup policies on volumes in the Block Storage service
  + Support for specifying the network type when launching virtual
    machine instances in the Compute service
  + Support for Monitoring service integration in the Health Checks service
  + The tenant_id parameter is now id (Id of the Transfer Application Entitlement)
    for get_transfer_appliance_entitlement in TransferApplianceEntitlementClient
  + The topic_attributes_details parameter is now required for update_topic
    in NotificationControlPlaneClient
  + The Audit service version was bumped to 20190901, use older version of Python SDK for Audit service version 20160918
- Update file list to fix Python imports for unvendoring
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.5.2
  + Support for required tags in the Identity service
  + Support for work requests on tagging operations in the Identity service
  + Support for enumerated tag values in the Identity service
  + Support for moving dynamic routing gateway resources across
    compartments in the Networking service
  + Support for migrating zones from Dyn managed DNS to OCI in the DNS service
  + Support for fast provisioning for virtual machine databases in the Database service
- from version 2.5.1
  + Support for selecting the Terraform version to use in the Resource Manager service
  + Support for bucket re-encryption in the Object Storage service
  + Support for enabling / disabling bucket-level events in the Object Storage service
- from version 2.5.0
  + Support for importing state files in the Resource Manager service
  + Support for Exadata Cloud at Customer in the Database service
  + Support for free tier resources and system tags in the Load Balancing service
  + Support for free tier resources and system tags in the Compute service
  + Support for free tier resources and system tags in the Block Storage service
  + Support for free tier and system tags on autonomous databases in the Database service
  + The availability_domain parameter is now a kwarg for
    list_db_system_shapes in DatabaseClient
  + The model CreateDbHomeWithDbSystemIdBase was renamed CreateDbHomeBase
    and the parameter db_system_id was removed
  + The parameter create_db_home_with_db_system_id_details for create_db_home in
    DatabaseClient changed from CreateDbHomeWithDbSystemIdBase to CreateDbHomeBase
* Tue Sep 10 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.4.0
  + Support for specifying the autoBackupWindow field for
    scheduling backups in the Database service
  + Support for network security groups on autonomous Exadata
    infrastructure in the Database service
  + Support for Kubernetes secrets encryption in customer clusters,
    regional subnets, and cluster authentication for instance
    principals in the Container Engine for Kubernetes service
  + Support for the Oracle Content and Experience service
  + The etag header has been removed from the response for
    NotificationControlPlaneClient.change_topic_compartment
    and NotificationDataPlaneClient.change_subscription_compartment
- from version 2.3.3
  + Support for the Sydney (SYD) region
  + Support for managing cluster networks in the Compute Autoscaling service
  + Support for tracking asynchronous operations via work
    requests in the Database service
- Update file list to fix Python imports for unvendoring
* Wed Aug 28 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.3.2
  + Support for the Sao Paulo (GRU) region
  + Support for dedicated virtual machine hosts in the Compute service
  + Support for resource groups in metrics and alarms in the Monitoring service
- Add patch to relax Python dependencies in requirements.txt and setup.py
  + ops_relax-python-depends.patch
* Mon Aug 26 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.3.1
  + Support for the Limits service
  + Support for archiving to Object Storage in the Streaming service
  + Support for etags on resources in the Streaming service
  + Support for Key Management service (KMS) encryption of file
    systems in the File Storage service
  + Support for moving public IP, DHCP, local peering gateway, internet
    gateway, network security group, and DRG attachment resources across
    compartments in the Networking service
  + Support for multi-origin, basic cache, certificate mapping, and OCI
    Monitoring service integration in the Web Application Acceleration
    and Security service
* Fri Aug 16 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.3.0
  + Support for the Data Transfer service
  + Support for the Zurich (ZRH) region
  + oci.waas.WafLog.timestamp type changed from str to datetime
  + oci.waas.models.Certificate.issuer_name type changed from
    oci.waas.models.CertificateSubjectName to oci.waas.models.CerticateIssuerName
  + "PURGE_WAAS_POLICY" removed as option for oci.waas.models.WorkRequest.operation_type
  + "PURGE_WAAS_POLICY" removed as option for oci.waas.models.WorkRequestSummary.operation_type
- from version 2.2.21
  + Support for IPv6 load balancers in the Load Balancing service
  + Support for IPv6 on VCN and FastConnect resources in the Networking service
- Update file list to fix Python imports for unvendoring
* Fri Aug  2 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.2.20
  + Support for the Mumbai (BOM) region
  + Support for the Events service
  + Support for moving streams across compartments in the Streaming service
  + Support for moving FastConnect resources across
    compartments in the Networking service
  + Support for moving policies across compartments in the
    Web Application Acceleration and Security service
  + Support for tagging FastConnect resources in the Networking service
- from version 2.2.19
  + Support for moving resources across compartments in the Database service
  + Support for moving resources across compartments in the Health Checks service
  + Support for moving alarms across compartments in the Monitoring service
  + Support for creating instance configurations from
    running instances in the Compute service
  + Support for setting up budget alerts for cost tracking tags in the Budgets service
- from version 2.2.18
  + Support for the Functions service
  + Support for the Quotas service
  + Support for moving resources across compartments in the DNS service
  + Support for moving instances across compartments in the Compute service
  + Support for moving keys and vaults across compartments in the Key Management service
  + Support for moving topics and subscriptions across
    compartments in the Notifications service
  + Support for moving load balancers across compartments in the Load Balancing service
  + Support for specifying permitted REST methods in load
    balancer rule sets in the Load Balancing service
  + Support for configuring cookie session persistence in
    backend sets in the Load Balancing service
  + Support for ACL rules in rule sets in the Load Balancing service
  + Support for move compartment tree in the Identity service
  + Support for specifying and returning a KMS key in
    backup operations in the Block Storage service
  + Support for transit routing in the Networking service
  + Support for authenticating via Resource Principals. An example of how to
    use resource principals is available on GitHub. This authentication method
    is only supported within the Functions service at this time.
- Remove bogus python-configparser2 dependency from BuildRequires
- Update file list to fix Python imports for unvendoring
* Tue Jul 16 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.2.17
  + Support for network security groups in the Load Balancing service
  + Support for network security groups in Core Services
  + Support for network security groups on database systems in the Database service
  + Support for creating autonomous transaction processing and autonomous
    data warehouse previews in the Database service
  + Support for getting the load balancer attachments
    of instance pools in the Compute service
  + Support for moving resources across compartments in the Resource Manager service
  + Support for moving VCN resources across compartments in the Networking service
- from version 2.2.16
  + Support for moving images, instance configurations, and
    instance pools across compartments in Core Services
  + Support for moving autoscaling configurations across compartments
    in the Compute Autoscaling service
  + Fixed a bug where the Streaming service's endpoints in Tokyo, Seoul,
    and future regions were not reachable from the SDK
* Mon Jul  1 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.2.15
  + Support for moving senders across compartments in the Email service
  + Support for moving NAT gateway resources across compartments in Core Services
* Mon Jun 24 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.2.14
  + Support for moving service gateway resources
    across compartments in Core Services
  + Support for moving block storage resources
    across compartments in Core Services
  + Support for key deletion in the Key Management service
* Wed Jun 19 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 2.2.13
